@@ -3,9 +3,9 @@
 package Perinci::CmdLine;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-19'; # DATE
+our $DATE = '2024-11-12'; # DATE
 our $DIST = 'Perinci-CmdLine'; # DIST
-our $VERSION = '2.000.0'; # VERSION
+our $VERSION = '2.000.1'; # VERSION
 
 sub new {
     die "Perinci::CmdLine::Lite is empty. Please use of the implementations: Perinci::CmdLine::Plugin, Perinci::CmdLine::Inline, etc";
@@ -26,7 +26,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 2.000.0 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2021-12-19.
+This document describes version 2.000.1 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2024-11-12.
 
 =head1 DESCRIPTION
 
@@ -82,13 +82,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
